==> apache-camel-3.0.0-RC1-src.zip: apache-camel-3.0.0-RC1/components/camel-mail/src/test/java/org/apache/camel/component/mail/MailSearchTermUriConfigBeanTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.mail;

import org.apache.camel.BindToRegistry;
import org.apache.camel.builder.RouteBuilder;

public class MailSearchTermUriConfigBeanTest extends MailSearchTermUriConfigTest {

    @BindToRegistry("mySearchTerm")
    public SimpleSearchTerm addSearchTerm() throws Exception {
        SimpleSearchTerm mySearchTerm = new SimpleSearchTerm();
        mySearchTerm.setSubjectOrBody("Camel");

        return mySearchTerm;
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            public void configure() throws Exception {
                from("pop3://bill@localhost?password=secret&searchTerm=#mySearchTerm").to("mock:result");
            }
        };
    }

}

==> apache-camel-4.0.0-RC1-src.zip: apache-camel-4.0.0-RC1/components/camel-mail/src/test/java/org/apache/camel/component/mail/MailSearchTermUriConfigBeanTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.mail;

import org.apache.camel.BindToRegistry;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mail.Mailbox.MailboxUser;
import org.apache.camel.component.mail.Mailbox.Protocol;

public class MailSearchTermUriConfigBeanTest extends MailSearchTermUriConfigTest {
    @SuppressWarnings({ "checkstyle:ConstantName" })
    private static final MailboxUser bill = Mailbox.getOrCreateUser("bill", "secret");

    @BindToRegistry("mySearchTerm")
    public SimpleSearchTerm addSearchTerm() {
        SimpleSearchTerm mySearchTerm = new SimpleSearchTerm();
        mySearchTerm.setSubjectOrBody("Camel");

        return mySearchTerm;
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                from(bill.uriPrefix(Protocol.pop3) + "&searchTerm=#mySearchTerm").to("mock:result");
            }
        };
    }

}
